Enum RelationshipAccessor
pub enum RelationshipAccessor {
Relationship {
entity_field_offset: usize,
linked_spawn: bool,
allow_self_referential: bool,
relationship_target: ComponentId,
},
RelationshipTarget {
iter: for<'a> unsafe fn(Ptr<'a>) -> Box<dyn Iterator<Item = Entity> + 'a>,
linked_spawn: bool,
allow_self_referential: bool,
relationship: ComponentId,
},
}Expand description
This enum describes a way to access the entities of Relationship and RelationshipTarget components
in a type-erased context.
Variants
Relationship
This component is a Relationship.
Fields
entity_field_offset: usizeOffset of the field containing Entity from the base of the component.
Dynamic equivalent of Relationship::get.
linked_spawn: boolValue of RelationshipTarget::LINKED_SPAWN for the Relationship::RelationshipTarget of this Relationship.
allow_self_referential: boolValue of Relationship::ALLOW_SELF_REFERENTIAL of this Relationship.
relationship_target: ComponentIdComponentId of the RelationshipTarget counterpart.
RelationshipTarget
This component is a RelationshipTarget.
Fields
iter: for<'a> unsafe fn(Ptr<'a>) -> Box<dyn Iterator<Item = Entity> + 'a>Function that returns an iterator over all Entitys of this RelationshipTarget’s collection.
Dynamic equivalent of RelationshipTarget::iter.
Safety
Passed pointer must point to the value of the same component as the one that this accessor was registered to.
linked_spawn: boolValue of RelationshipTarget::LINKED_SPAWN of this RelationshipTarget.
allow_self_referential: boolValue of Relationship::ALLOW_SELF_REFERENTIAL for the Relationship of this RelationshipTarget.
relationship: ComponentIdComponentId of the Relationship counterpart.
Implementations
impl RelationshipAccessor
impl RelationshipAccessor
pub fn counterpart_id(&self) -> ComponentId
pub fn counterpart_id(&self) -> ComponentId
Returns ComponentId of RelationshipTarget for this Relationship and vice-versa.
pub fn linked_spawn(&self) -> bool
pub fn linked_spawn(&self) -> bool
Returns the value of RelationshipTarget::LINKED_SPAWN.
pub fn allow_self_referential(&self) -> bool
pub fn allow_self_referential(&self) -> bool
Returns the value of Relationship::ALLOW_SELF_REFERENTIAL.